@@ -1,63 +1,25 @@
 <?php
-/**
- * HUBzero CMS
- *
- * Copyright 2005-2011 Purdue University. All rights reserved.
- *
- * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
- *
- * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
- * software: you can redistribute it and/or modify it under the terms of
- * the GNU Lesser General Public License as published by the Free Software
- * Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * HUBzero is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * HUBzero is a registered trademark of Purdue University.
- *
- * @package   hubzero-cms
- * @author    Sam Wilson <samwilson@purdue.edu>
- * @copyright Copyright 2011 Purdue University. All rights reserved.
- * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
- */
-
-// no direct access
-defined('_JEXEC') or die('Restricted access');
 
 /**
-* Default file asset handler class
+* Default Asset handler class
 */
 class FileAssetHandler extends AssetHandler
 {
-	/**
-	 * Class info
-	 *
-	 * Action message - what the user will see if presented with multiple handlers for this extension
-	 * Responds to    - what extensions this handler responds to
-	 *
-	 * @var array
-	 **/
-	protected static $info = array(
-		'action_message' => 'Post notes or slides (i.e. a downloadable file)',
-		'responds_to'    => array(
-			'txt', 'pdf', 'jpg', 'jpeg', 'gif', 'png', 'ppt',
-			'pptx', 'pps', 'ppsx', 'doc', 'docx', 'xls', 'xlsx',
-			'zip', 'tgz', 'tar', 'mp3', 'm', 'cpp', 'c', 'r',
-			'wm2d', 'slx', 'srt'),
+	private static $info = array(
+			'action_message' => 'As a standard downloadable file',
+			'responds_to'    => array('txt', 'pdf'),
 		);
 
-	/**
-	 * Create method for this handler
-	 *
-	 * @return array of assets created
-	 **/
+	public static function getMessage()
+	{
+		return self::$info['action_message'];
+	}
+
+	public static function getExtensions()
+	{
+		return self::$info['responds_to'];
+	}
+
 	public function create()
 	{
 		// Include needed files
@@ -86,20 +48,19 @@ class FileAssetHandler extends AssetHandler
 
 		// @FIXME: should these come from the global settings, or should they be courses specific
 		// Get config
-		$config = JComponentHelper::getParams('com_media');
+		$config =& JComponentHelper::getParams('com_media');
 
 		// Max upload size
-		$sizeLimit = (int) $config->get('upload_maxsize');
-		$sizeLimit = $sizeLimit * 1024 * 1024;
+		$sizeLimit = $config->get('upload_maxsize');
 
 		// Check to make sure we have a file and its not too big
-		if ($size == 0)
+		if ($size == 0) 
 		{
 			return array('error' => 'File is empty');
 		}
-		if ($size > $sizeLimit)
+		if ($size > $sizeLimit) 
 		{
-			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', \Hubzero\Utility\Number::formatBytes($sizeLimit));
+			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', Hubzero_View_Helper_Html::formatSize($sizeLimit));
 			return array('error' => "File is too large. Max file upload size is $max");
 		}
 
@@ -108,9 +69,8 @@ class FileAssetHandler extends AssetHandler
 
 		$this->asset['title']      = $filename;
 		$this->asset['type']       = (!empty($this->asset['type'])) ? $this->asset['type'] : 'file';
-		$this->asset['subtype']    = (!empty($this->asset['subtype'])) ? $this->asset['subtype'] : 'file';
 		$this->asset['url']        = $file;
-		$this->asset['created']    = JFactory::getDate()->toSql();
+		$this->asset['created']    = date('Y-m-d H:i:s');
 		$this->asset['created_by'] = JFactory::getApplication()->getAuthn('user_id');
 		$this->asset['course_id']  = JRequest::getInt('course_id', 0);
 
@@ -134,7 +94,7 @@ class FileAssetHandler extends AssetHandler
 		}
 
 		// Get courses config
-		$cconfig = JComponentHelper::getParams('com_courses');
+		$cconfig =& JComponentHelper::getParams('com_courses');
 
 		// Build the upload path if it doesn't exist
 		$uploadDirectory = JPATH_ROOT . DS . trim($cconfig->get('uploadpath', '/site/courses'), DS) . DS . $this->asset['course_id'] . DS . $this->assoc['asset_id'] . DS;
@@ -152,44 +112,21 @@ class FileAssetHandler extends AssetHandler
 			return array('error' => 'Server error. Upload directory isn\'t writable');
 		}
 
+		// @FIXME: cleanup asset and asset association if directory creation fails
+
 		// Get the final file path
 		$target_path = $uploadDirectory . $filename . '.' . $ext;
 
 		// Move the file to the site folder
+		// FIXME: is this ok?
 		set_time_limit(60);
-
-		// Scan for viruses
-		if (!JFile::isSafe($_FILES['files']['tmp_name'][0]))
-		{
-			// Scan failed, delete asset and association and return an error
-			$assetObj->delete();
-			$assocObj->delete();
-			JFolder::delete($uploadDirectory);
-			return array('error' => 'File rejected because the anti-virus scan failed.');
-		}
-
-		if (!$move = move_uploaded_file($_FILES['files']['tmp_name'][0], $target_path))
-		{
-			// Move failed, delete asset and association and return an error
-			$assetObj->delete();
-			$assocObj->delete();
-			JFolder::delete($uploadDirectory);
-			return array('error' => 'Move file failed');
-		}
-
-		// Get the url to return to the page
-		$course_id      = JRequest::getInt('course_id', 0);
-		$offering_alias = JRequest::getCmd('offering', '');
-		$course         = new CoursesModelCourse($course_id);
-
-		$url = JRoute::_('index.php?option=com_courses&controller=offering&gid='.$course->get('alias').'&offering='.$offering_alias.'&asset='.$assetObj->get('id'));
+		move_uploaded_file($_FILES['files']['tmp_name'][0], $target_path);
 
 		$return_info = array(
 			'asset_id'       => $this->assoc['asset_id'],
 			'asset_title'    => $this->asset['title'],
 			'asset_type'     => $this->asset['type'],
-			'asset_subtype'  => $this->asset['subtype'],
-			'asset_url'      => $url,
+			'asset_url'      => CoursesModelAsset::getInstance($this->assoc['asset_id'])->path($this->asset['course_id']),
 			'course_id'      => $this->asset['course_id'],
 			'offering_alias' => JRequest::getCmd('offering', ''),
 			'scope_id'       => $this->assoc['scope_id'],
@@ -201,4 +138,19 @@ class FileAssetHandler extends AssetHandler
 		// Return info
 		return array('assets' => $return_info);
 	}
+
+	public function edit()
+	{
+
+	}
+
+	public function delete()
+	{
+
+	}
+
+	public function render()
+	{
+
+	}
 }
\ No newline at end of file
